@@ -70,7 +70,7 @@ gcm_test_edid_func (void)
         g_assert (ret);
 
         g_assert_cmpstr (gcm_edid_get_monitor_name (edid), ==, NULL);
-        g_assert_cmpstr (gcm_edid_get_vendor_name (edid), ==, "IBM France");
+        g_assert_cmpstr (gcm_edid_get_vendor_name (edid), ==, "IBM Brasil");
         g_assert_cmpstr (gcm_edid_get_serial_number (edid), ==, NULL);
         g_assert_cmpstr (gcm_edid_get_eisa_id (edid), ==, "LTN154P2-L05");
         g_assert_cmpstr (gcm_edid_get_checksum (edid), ==, "e1865128c7cd5e5ed49ecfc8102f6f9c");
